package com.sun.org.apache.xml.internal.dtm;

import com.sun.org.apache.xml.internal.utils.PrefixResolver;
import org.w3c.dom.Node;
import javax.xml.transform.Source;
import com.sun.org.apache.xml.internal.dtm.ref.DTMManagerDefault;
import com.sun.org.apache.xml.internal.utils.XMLStringFactory;

public abstract class DTMManager
{
    protected XMLStringFactory m_xsf;
    private boolean _overrideDefaultParser;
    public boolean m_incremental;
    public boolean m_source_location;
    public static final int IDENT_DTM_NODE_BITS = 16;
    public static final int IDENT_NODE_DEFAULT = 65535;
    public static final int IDENT_DTM_DEFAULT = -65536;
    public static final int IDENT_MAX_DTMS = 65536;
    
    protected DTMManager() {
        this.m_xsf = null;
        this.m_incremental = false;
        this.m_source_location = false;
    }
    
    public XMLStringFactory getXMLStringFactory() {
        return this.m_xsf;
    }
    
    public void setXMLStringFactory(XMLStringFactory xsf) {
        this.m_xsf = xsf;
    }
    
    public static DTMManager newInstance(XMLStringFactory xsf) throws DTMException {
        DTMManager factoryImpl = new DTMManagerDefault();
        factoryImpl.setXMLStringFactory(xsf);
        return factoryImpl;
    }
    
    public abstract DTM getDTM(Source p0, boolean p1, DTMWSFilter p2, boolean p3, boolean p4);
    
    public abstract DTM getDTM(int p0);
    
    public abstract int getDTMHandleFromNode(Node p0);
    
    public abstract DTM createDocumentFragment();
    
    public abstract boolean release(DTM p0, boolean p1);
    
    public abstract DTMIterator createDTMIterator(Object p0, int p1);
    
    public abstract DTMIterator createDTMIterator(String p0, PrefixResolver p1);
    
    public abstract DTMIterator createDTMIterator(int p0, DTMFilter p1, boolean p2);
    
    public abstract DTMIterator createDTMIterator(int p0);
    
    public boolean getIncremental() {
        return this.m_incremental;
    }
    
    public void setIncremental(boolean incremental) {
        this.m_incremental = incremental;
    }
    
    public boolean getSource_location() {
        return this.m_source_location;
    }
    
    public void setSource_location(boolean sourceLocation) {
        this.m_source_location = sourceLocation;
    }
    
    public boolean overrideDefaultParser() {
        return this._overrideDefaultParser;
    }
    
    public void setOverrideDefaultParser(boolean flag) {
        this._overrideDefaultParser = flag;
    }
    
    public abstract int getDTMIdentity(DTM p0);
    
    public int getDTMIdentityMask() {
        return -65536;
    }
    
    public int getNodeIdentityMask() {
        return 65535;
    }
}
